@@ -1,5 +1,5 @@
 def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interfaces_and_types=False, print_width=120,
-                 p=False):
+                 p=False, show_failed_output=False, show_graphs=False, show_arguments=False, no_of_arguments=2):
     from collections import defaultdict
     if not categorize:
         return_list = []
@@ -7,6 +7,7 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interface
     failed = defaultdict(set)
     passed_ = defaultdict(lambda: defaultdict(set))
     failed_ = defaultdict(lambda: defaultdict(set))
+    failed_output = defaultdict(dict)
     x = arg
 
     for method in (set(dir(arg)) | (set(dir(type(x))) - set(dir(x)))):
@@ -14,6 +15,7 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interface
             type_ = type(eval(f'x.{method}'))
         except:
             failed[f'{arg}'].add(method)
+            failed_output[f'{arg}'].update()
             continue
         try:
             qualname = eval(f'x.{method}.__qualname__')
@@ -23,10 +25,15 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interface
         except:
             failed[f'{arg}'].add(method)
             failed_[f'{arg}'][type_].add(method)
+            if show_failed_output:
+                output = eval(f'x.{method}')
+                failed_output[f'{arg}'].update({method: output})
     if categorize:
         return_list = [{'passed': passed}, {'failed': failed}]
     if show_types:
         return_list.extend(({'passed_types': passed_}, {'failed_types': failed_}))
+    if show_failed_output:
+        return_list.append({'failed_output': failed_output})
     if interfaces_and_types:
         import collections.abc
         import types
@@ -86,6 +93,32 @@ def enhanced_dir(arg, categorize=True, show_types=False, checks=False, interface
             checks_['iterable'] = False
         return_list.append([checks_])
 
+    if show_graphs:
+        import matplotlib.pyplot as plt
+        import seaborn
+        plt.rcParams["figure.figsize"] = (10, 6)
+        dc = {i: len(j) for i, j in passed[f'{arg}'].items()}
+        dc_1 = {i: len(j) for i, j in {**passed_[f'{arg}'], **failed_[f'{arg}']}.items()}
+
+        data, keys = [dc.values(), dc_1.values()], [dc.keys(), dc_1.keys()]
+        fig, axes = plt.subplots(1, 2)
+        palette_color = seaborn.color_palette('bright')
+
+        axes[0].pie(data[0], labels=keys[0], colors=palette_color, autopct='%.0f%%')
+        axes[1].pie(data[1], labels=keys[1], colors=palette_color, autopct='%.0f%%')
+
+        plt.subplots_adjust(left=0.1, bottom=0.1, right=0.9, top=0.9, wspace=0.2, hspace=0.4)
+
+        plt.show()
+
+    if show_arguments:
+        import enhanced_dir
+        for i, j in passed[f'{arg}'].items():
+            for t in j:
+                return_list.append([f"""{arg}.{t}: {enhanced_dir.argument_inspector(f"{arg}.{t}", 
+                                                                                    no_of_arguments=no_of_arguments,
+                                                                                    show_output=False)}"""])
+
     if p:
         from pprint import pprint
         pprint(return_list, compact=True, width=print_width)
@@ -234,12 +267,12 @@ extended_builtins = ['Ellipsis', 'False', 'None', 'NotImplemented', 'True', 'abs
                      '(lambda x: 1).__code__.co_positions', '(type.__dict__)',
                      '((lambda: (yield))())', 'dict().keys', 'dict().values', 'dict().items']
 
-external_checks = {'imports': 'from collections import Counter, namedtuple, defaultdict, OrderedDict;\
+external_checks = {'imports': 'from collections import Counter, namedtuple, defaultdict, OrderedDict, ChainMap, deque;\
                                from types import SimpleNamespace;\
                                from fractions import Fraction;\
                                from decimal import Decimal;',
                    'modules': ['Counter', 'Fraction', 'Decimal', 'defaultdict', 'OrderedDict', 'namedtuple',
-                               'SimpleNamespace']}
+                               'SimpleNamespace', 'ChainMap', 'deque']}
 
 
 def argument_inspector(arg, lib=None, no_of_arguments=2, p=False, print_width=120, show_output=True):
@@ -439,15 +472,11 @@ def argument_inspector(arg, lib=None, no_of_arguments=2, p=False, print_width=12
 
 
 inspection_arguments = [1, 0, 1.2, 'abc', '1', '0', '1.2', '1/2', {1, 2, 3}, {'a': 1, 'b': 2}, (1, 2, 3),
-                        [(2, 5), (3, 2)], [1, 2, 3], [1, 0, 1, 0],
-                        {'a', 'b', 'c'}, ('a', 'b', 'c'), ['a', 'b', 'c'], 1 + 2j,
-                        b'2', b'a', bytearray(1), frozenset({1, 2, 3}), frozenset({'a', 'b', 'c'}),
-                        '(lambda x: x < 5)', 'range(2)', "enumerate('a')", '(iter([1, 2, 3]))',
-                        '(iter(reversed([1, 2, 3])))',
-                        '(iter(range(5)))',
-                        '(iter({1, 2, 3}))', "(iter('abc'))", '(iter((1, 2, 3)))', "(iter({'a': 1, 'b': 2}.items()))",
-                        "(iter(zip((0, 1, 2), 'abc')))",
-                        "(iter({'a': 1, 'b': 2}.keys()))", "(iter({'a': 1, 'b': 2}.values()))",
-                        ({'a': 1, 'b': 2}.keys()),
-                        ({'a': 1, 'b': 2}.values()), ({'a': 1, 'b': 2}.items()), "(iter(b'2'))", "(iter(b'a'))",
-                        '(iter(bytearray(1)))']
+                        [(2, 5), (3, 2)], [1, 2, 3], [1, 0, 1, 0], {'a', 'b', 'c'}, ('a', 'b', 'c'), ['a', 'b', 'c'],
+                        1 + 2j, b'2', b'a', bytearray(1), frozenset({1, 2, 3}), frozenset({'a', 'b', 'c'}),
+                        '(lambda x: x < 5)', 'range(2)', "enumerate('a')", '(iter([1, 2, 3]))', '(iter(range(5)))',
+                        '(iter(reversed([1, 2, 3])))', '(iter({1, 2, 3}))', "(iter('abc'))", '(iter((1, 2, 3)))',
+                        "(iter({'a': 1, 'b': 2}.items()))", "(iter(zip((0, 1, 2), 'abc')))",
+                        "(iter({'a': 1, 'b': 2}.keys()))",  "(iter({'a': 1, 'b': 2}.values()))",
+                        ({'a': 1, 'b': 2}.keys()), ({'a': 1, 'b': 2}.values()), ({'a': 1, 'b': 2}.items()),
+                        "(iter(b'2'))", "(iter(b'a'))", '(iter(bytearray(1)))']
